/*
 * Created on 11.02.2005
 *
 */
package net.sit.dialog.cli;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import net.sit.dialog.cfg.Cfg;
import net.sit.dialog.srv.DialogServerIF;

import org.apache.log4j.Logger;

/**
 * @author Christoph Sandhaus
 * 
 */
public class ClientRMIConnector {

    static Logger logger = Logger.getLogger(ClientRMIConnector.class.getName());

    private static DialogServerIF server;
    private String serverIp;
    
    public ClientRMIConnector(String serverIp){
        this.serverIp = serverIp;
    }

    public boolean displayMessageDialog(String message) throws ServerDownException {
        if (connectToRmiServer()) {
            try {
                logger.info("Rufe RMI Methode displayMessageDialog ...");
                server.displayMessageDialog(message);
            } catch (RemoteException e) {
                throw new ServerDownException();
            }
            
        } else
        	logger.error("Anfrage nicht durchgefhrt");
        return true;
    }

    private boolean connectToRmiServer() throws ServerDownException{

        if (server == null) {
            try {
                String serverURL = "rmi://" + serverIp +":"+Cfg.RMI_SERVER_PORT +"/";
                String dialogURL = serverURL + Cfg.RMI_SERVER_NAME;

                // Im Debugging Modus die Server Liste anzeigen
                if (logger.isDebugEnabled()) {
                    logger.debug("Hole Stub Liste vom Server '" + serverURL + "'");

                    // RMI Registry abfragen
                    String stubList[] = Naming.list(serverURL);

                    int i;
                    int len = stubList.length;

                    logger.debug(len + " Registry-Eintre gefunden:");

                    for (i = 0; i < len; i++)
                        logger.debug("- " + stubList[i].toString());
                }

                // jetzt mit dem Server verbinden
                server = (DialogServerIF) Naming.lookup(dialogURL);

                logger.info("Verbindung aufgebaut zu '" + dialogURL);

            } catch (MalformedURLException e1) {
                logger.info("MaleformedURLException: " + e1.getMessage());
                return false;

            } catch (NotBoundException e1) {
                logger.info("NotBoundException: " + e1.getMessage());
                return false;
            } catch (RemoteException e1) {
                logger.info("RemoteException: " + e1.getMessage());
                throw new ServerDownException();
            }

        }
        
        return true;
    }
}
